==> pyvispr-2024.42.tar.gz: pyvispr-2024.42/package/pyvispr/interface/widget/doc_area.py <==
"""
Copyright CNRS/Inria/UniCA
Contributor(s): Eric Debreuve (eric.debreuve@cnrs.fr) since 2017
SEE COPYRIGHT NOTICE BELOW
"""

import dataclasses as d

from pyvispr.config.appearance.color import HIGHLIGHT_BRUSH
from pyvispr.extension.object.field import NON_INIT_FIELD
from pyvispr.extension.qt.imports import qtcr, qtgi, qtwg
from pyvispr.runtime.backend import SCREEN_BACKEND


@d.dataclass(slots=True, repr=False, eq=False)
class _highlighter_t(qtgi.QSyntaxHighlighter):
    search: str = NON_INIT_FIELD
    format: qtgi.QTextCharFormat = NON_INIT_FIELD

    document: d.InitVar[qtgi.QTextDocument | None] = None

    def __post_init__(self, document: qtgi.QTextDocument | None) -> None:
        """"""
        qtgi.QSyntaxHighlighter.__init__(self, document)

        self.search = ""

        format_ = qtgi.QTextCharFormat()
        format_.setBackground(HIGHLIGHT_BRUSH)
        self.format = format_

    def highlightBlock(self, text: str, /) -> None:
        """"""
        if self.search.__len__() == 0:
            return

        search = qtcr.QRegularExpression(self.search)
        iterator = search.globalMatch(text)
        while iterator.hasNext():
            match = iterator.next()
            self.setFormat(match.capturedStart(), match.capturedLength(), self.format)


@d.dataclass(slots=True, repr=False, eq=False)
class doc_wgt_t(qtwg.QWidget):
    content_wgt: qtwg.QTextEdit = NON_INIT_FIELD
    filter_wgt: qtwg.QLineEdit = NON_INIT_FIELD
    highlighter: _highlighter_t = NON_INIT_FIELD

    def __post_init__(self) -> None:
        """"""
        qtwg.QWidget.__init__(self)

        content_wgt = qtwg.QTextEdit()
        content_wgt.setReadOnly(True)
        content_wgt.setLineWrapMode(qtwg.QTextEdit.LineWrapMode.NoWrap)
        self.content_wgt = content_wgt

        filter_wgt = qtwg.QLineEdit()
        filter_wgt.setPlaceholderText("Highlight words in documentation")
        filter_wgt.setClearButtonEnabled(True)
        self.filter_wgt = filter_wgt

        highlighter = _highlighter_t(document=content_wgt.document())
        self.highlighter = highlighter

        layout = qtwg.QVBoxLayout()
        layout.setContentsMargins(0, 0, 0, 0)
        layout.addWidget(content_wgt)
        layout.addWidget(filter_wgt)
        self.setLayout(layout)

        SCREEN_BACKEND.AddMessageCanal(filter_wgt, "textEdited", self.HighlightSearch)

    def HighlightSearch(self, new_search: str, /) -> None:
        """"""
        highlighter = self.highlighter
        highlighter.search = new_search
        highlighter.rehighlight()


"""
COPYRIGHT NOTICE

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use,
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info".

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability.

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or
data to be ensured and,  more generally, to use and operate it in the
same conditions as regards security.

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.

SEE LICENCE NOTICE: file README-LICENCE-utf8.txt at project source root.

This software is being developed by Eric Debreuve, a CNRS employee and
member of team Morpheme.
Team Morpheme is a joint team between Inria, CNRS, and UniCA.
It is hosted by the Centre Inria d'Université Côte d'Azur, Laboratory
I3S, and Laboratory iBV.

CNRS: https://www.cnrs.fr/index.php/en
Inria: https://www.inria.fr/en/
UniCA: https://univ-cotedazur.eu/
Centre Inria d'Université Côte d'Azur: https://www.inria.fr/en/centre/sophia/
I3S: https://www.i3s.unice.fr/en/
iBV: http://ibv.unice.fr/
Team Morpheme: https://team.inria.fr/morpheme/
"""

==> pyvispr-2024.44.tar.gz: pyvispr-2024.44/package/pyvispr/interface/widget/doc_area.py <==
"""
Copyright CNRS/Inria/UniCA
Contributor(s): Eric Debreuve (eric.debreuve@cnrs.fr) since 2017
SEE COPYRIGHT NOTICE BELOW
"""

import dataclasses as d

from pyvispr.extension.object.field import NON_INIT_FIELD
from pyvispr.extension.qt.imports import qt_e, qtwg
from pyvispr.interface.widget.highlighter import highlighter_t
from pyvispr.runtime.backend import SCREEN_BACKEND


@d.dataclass(slots=True, repr=False, eq=False)
class doc_wgt_t(qtwg.QWidget):
    content_wgt: qtwg.QTextEdit = NON_INIT_FIELD
    filter_wgt: qtwg.QLineEdit = NON_INIT_FIELD
    highlighter: highlighter_t = NON_INIT_FIELD

    def __post_init__(self) -> None:
        """"""
        qtwg.QWidget.__init__(self)

        content_wgt = qtwg.QTextEdit()
        content_wgt.setReadOnly(True)
        content_wgt.setLineWrapMode(qtwg.QTextEdit.LineWrapMode.NoWrap)
        content_wgt.setTextInteractionFlags(
            qt_e.TextInteractionFlag.TextSelectableByKeyboard
            | qt_e.TextInteractionFlag.TextSelectableByMouse
        )
        self.content_wgt = content_wgt

        filter_wgt = qtwg.QLineEdit()
        filter_wgt.setPlaceholderText("Highlight words in documentation")
        filter_wgt.setClearButtonEnabled(True)
        self.filter_wgt = filter_wgt

        highlighter = highlighter_t(document=content_wgt.document())
        self.highlighter = highlighter

        layout = qtwg.QVBoxLayout()
        layout.setContentsMargins(0, 0, 0, 0)
        layout.addWidget(content_wgt)
        layout.addWidget(filter_wgt)
        self.setLayout(layout)

        SCREEN_BACKEND.AddMessageCanal(filter_wgt, "textEdited", self.HighlightSearch)

    def HighlightSearch(self, new_search: str, /) -> None:
        """"""
        highlighter = self.highlighter
        highlighter.search = new_search
        highlighter.rehighlight()


"""
COPYRIGHT NOTICE

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use,
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info".

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability.

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or
data to be ensured and,  more generally, to use and operate it in the
same conditions as regards security.

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.

SEE LICENCE NOTICE: file README-LICENCE-utf8.txt at project source root.

This software is being developed by Eric Debreuve, a CNRS employee and
member of team Morpheme.
Team Morpheme is a joint team between Inria, CNRS, and UniCA.
It is hosted by the Centre Inria d'Université Côte d'Azur, Laboratory
I3S, and Laboratory iBV.

CNRS: https://www.cnrs.fr/index.php/en
Inria: https://www.inria.fr/en/
UniCA: https://univ-cotedazur.eu/
Centre Inria d'Université Côte d'Azur: https://www.inria.fr/en/centre/sophia/
I3S: https://www.i3s.unice.fr/en/
iBV: http://ibv.unice.fr/
Team Morpheme: https://team.inria.fr/morpheme/
"""
